Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/roundcube/roundcubemail.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
path: root/config
diff options
context:
space:
mode:
authorGithub-Citizen <80302627+Github-Citizen@users.noreply.github.com>2022-04-24 10:37:35 +0300
committerGitHub <noreply@github.com>2022-04-24 10:37:35 +0300
commit0e2858da974d52344f687fde18717fe01e7e9c70 (patch)
tree7f744758e2fe26dffa2af29bea4f5f50b2d4a314 /config
parent6303d3177e03846e7ca56f92091a2979dbb5b59e (diff)
Added link to logo image using $config['skin_logo'] (#8509)
Added ability to define a link URL for the logo image using $config['skin_logo']. Works by defining the `logo type` for $config['skin_logo'] as `[link]` for example: $config['skin_logo'] = ['elastic:*[link]' => 'https://www.example.com']; $config['skin_logo'] = ['[link]' => 'https://www.example.com']; Same relative path rules apply as when you define location of logo image file. Starting with `http://` or `https://` is absolute. Starting with a slash `/page.html` is relative to the skin directory ie `example.com/skins/elastic/page.html` Starting without a slash `page.html` is relative to the website root directory ie `example.com/page.html`
Diffstat (limited to 'config')
-rw-r--r--config/defaults.inc.php16
1 files changed, 12 insertions, 4 deletions
diff --git a/config/defaults.inc.php b/config/defaults.inc.php
index 35936c9ac..904524896 100644
--- a/config/defaults.inc.php
+++ b/config/defaults.inc.php
@@ -489,10 +489,12 @@ $config['blankpage_url'] = '/watermark.html';
// is made up of (up to) 3 parts:
// - skin name prefix (always with colon, can be replaced with *)
// - template name (or * for all templates)
// - logo type - it is used for logos used on multiple templates
// the available types include '[favicon]' for favicon, '[print]' for logo on all print
// templates (e.g. messageprint, contactprint) and '[small]' for small screen logo in supported skins
// '[dark]' and '[small-dark]' for dark mode logo in supported skins
//
// Example config for skin_logo
/*
@@ -501,6 +503,12 @@ $config['blankpage_url'] = '/watermark.html';
"elastic:login[small]" => "/images/logo_login_small.png",
// show the image /images/logo_login.png for the Login screen in the Elastic skin
"elastic:login" => "/images/logo_login.png",
+ // add a link to the logo on the Login screen in the Elastic skin
+ "elastic:login[link]" => "https://www.example.com",
+ // add a link to the logo on all screens in the Elastic skin
+ "elastic:*[link]" => "https://www.example.com",
+ // add a link to the logo on all screens for all skins
+ "[link]" => "https://www.example.com",
// show the image /images/logo_small.png in the Elastic skin
"elastic:*[small]" => "/images/logo_small.png",
// show the image /images/larry.png in the Larry skin
@@ -489,10 +489,12 @@ $config['blankpage_url'] = '/watermark.html';
// - skin name prefix (always with colon, can be replaced with *)
// - template name (or * for all templates)
-// - logo type - it is used for logos used on multiple templates
-// the available types include '[favicon]' for favicon, '[print]' for logo on all print
-// templates (e.g. messageprint, contactprint) and '[small]' for small screen logo in supported skins
-// '[dark]' and '[small-dark]' for dark mode logo in supported skins
+// - logo type - it is used for logos used on multiple templates and the available types include:
+// '[favicon]' for favicon
+// '[print]' for logo on all print templates (e.g. messageprint, contactprint)
+// '[small]' for small screen logo in supported skins
+// '[dark]' and '[small-dark]' for dark mode logo in supported skins
+// '[link]' for adding a URL link to the logo image
//
// Example config for skin_logo